"""In-process tests for the flatpak-report subcommand"""

import json
import logging
import pytest

from click.testing import CliRunner

from gi.repository import Modulemd

from _fedmod.cli import _cli_commands
from _fedmod.flatpak_generator import FlatpakGenerator

log = logging.getLogger(__name__)

def _generate_flatpak_report(rpms):
    cmd = ['flatpak-report', '--quiet']
    cmd.extend(rpms)
    runner = CliRunner()
    result = runner.invoke(_cli_commands, cmd)
    assert result.exit_code == 0

    return json.loads(result.output)


def test_flatpak_report():
    output = _generate_flatpak_report(['eog', 'gedit'])
    print(output.keys())

    packages = output['packages']

    # A package required by both specified rpms, in the runtime
    assert packages['gtk3'] == {
        'name': 'gtk3',
        'runtime': True,
        'used_by': ['eog', 'gedit']
    }

    # An extra package required only by eog
    assert packages['exempi'] == {
        'name': 'exempi',
        'runtime': False,
        'used_by': ['eog']
    }

    flatpaks = output['flatpaks']
    assert sorted(flatpaks.keys()) == ['eog', 'gedit']

    assert 'gtk3' in flatpaks['eog']['runtime']
    assert 'exempi' in flatpaks['eog']['extra']
